This is an automated email from the ASF dual-hosted git repository.
gmurthy pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-dispatch.git
The following commit(s) were added to refs/heads/main by this push:
new d56a71fd DISPATCH-2359: Added code to link cleanup that would send
detaches on link routed links.
d56a71fd is described below
commit d56a71fd8bdb8a50b99e5feb4d9b28857c4985bb
Author: Ganesh Murthy <[email protected]>
AuthorDate: Tue Aug 1 10:49:28 2023 -0400
DISPATCH-2359: Added code to link cleanup that would send detaches on link
routed links.
---
src/router_core/connections.c | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
diff --git a/src/router_core/connections.c b/src/router_core/connections.c
index 52c833f6..0c343ba0 100644
--- a/src/router_core/connections.c
+++ b/src/router_core/connections.c
@@ -1029,9 +1029,10 @@ static void qdr_link_cleanup_CT(qdr_core_t *core,
qdr_connection_t *conn, qdr_li
qdrc_endpoint_do_cleanup_CT(core, link->core_endpoint);
//
// If the link has a connected peer, unlink the peer
//
if (link->connected_link) {
+ qdr_link_outbound_detach_CT(core, link->connected_link, 0,
QDR_CONDITION_ROUTED_LINK_LOST, true);
link->connected_link->connected_link = 0;
link->connected_link = 0;
}
---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]
@@ -1029,9 +1029,10 @@ static void qdr_link_cleanup_CT(qdr_core_t *core,
qdrc_endpoint_do_cleanup_CT(core, link->core_endpoint);
//
- // If the link has a connected peer, unlink the peer
+ // If the link has a connected peer, detach and unlink the peer
//
if (link->connected_link) {